from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.horizontal_uncertainty import HorizontalUncertainty


T = TypeVar("T", bound="Origin")


@attr.s(auto_attribs=True)
class Origin:
    """
    Attributes:
        latitude (float):
        longitude (float):
        depth_m (float):
        uncertainty (Union[Unset, HorizontalUncertainty]):
    """

    latitude: float
    longitude: float
    depth_m: float
    uncertainty: Union[Unset, "HorizontalUncertainty"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        latitude = self.latitude
        longitude = self.longitude
        depth_m = self.depth_m
        uncertainty: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.uncertainty, Unset):
            uncertainty = self.uncertainty.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "latitude": latitude,
                "longitude": longitude,
                "depth_m": depth_m,
            }
        )
        if uncertainty is not UNSET:
            field_dict["uncertainty"] = uncertainty

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.horizontal_uncertainty import HorizontalUncertainty

        d = src_dict.copy()
        latitude = d.pop("latitude")

        longitude = d.pop("longitude")

        depth_m = d.pop("depth_m")

        _uncertainty = d.pop("uncertainty", UNSET)
        uncertainty: Union[Unset, HorizontalUncertainty]
        if isinstance(_uncertainty, Unset):
            uncertainty = UNSET
        else:
            uncertainty = HorizontalUncertainty.from_dict(_uncertainty)

        origin = cls(
            latitude=latitude,
            longitude=longitude,
            depth_m=depth_m,
            uncertainty=uncertainty,
        )

        origin.additional_properties = d
        return origin

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="StationLatLng")


@attr.s(auto_attribs=True)
class StationLatLng:
    """
    Attributes:
        code (str):
        latitude (float):
        longitude (float):
        elevation_km (float):
        depth_km (float):
    """

    code: str
    latitude: float
    longitude: float
    elevation_km: float
    depth_km: float
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        code = self.code
        latitude = self.latitude
        longitude = self.longitude
        elevation_km = self.elevation_km
        depth_km = self.depth_km

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "code": code,
                "latitude": latitude,
                "longitude": longitude,
                "elevation_km": elevation_km,
                "depth_km": depth_km,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        code = d.pop("code")

        latitude = d.pop("latitude")

        longitude = d.pop("longitude")

        elevation_km = d.pop("elevation_km")

        depth_km = d.pop("depth_km")

        station_lat_lng = cls(
            code=code,
            latitude=latitude,
            longitude=longitude,
            elevation_km=elevation_km,
            depth_km=depth_km,
        )

        station_lat_lng.additional_properties = d
        return station_lat_lng

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.first_motion import FirstMotion
from ..models.onset import Onset
from ..models.phase_descriptor_p import PhaseDescriptorP
from ..models.phase_descriptor_s import PhaseDescriptorS
from ..types import UNSET, Unset

T = TypeVar("T", bound="PhaseReading")


@attr.s(auto_attribs=True)
class PhaseReading:
    """
    Attributes:
        station_name (str):
        p_arrival (datetime.datetime):
        p_onset (Union[Unset, Onset]): An enumeration. Default: Onset.VALUE_2.
        p_phase_descriptor (Union[Unset, PhaseDescriptorP]): An enumeration. Default: PhaseDescriptorP.VALUE_4.
        p_first_motion (Union[Unset, FirstMotion]): An enumeration.
        s_arrival (Union[Unset, datetime.datetime]):
        p_weight (Union[Unset, int]):
        s_onset (Union[Unset, Onset]): An enumeration. Default: Onset.VALUE_2.
        s_phase_descriptor (Union[Unset, PhaseDescriptorS]): An enumeration. Default: PhaseDescriptorS.VALUE_3.
        s_remark (Union[Unset, str]):  Default: '   '.
        s_first_motion (Union[Unset, FirstMotion]): An enumeration.
        s_weight (Union[Unset, int]):
        amplitude (Union[Unset, float]):
        period (Union[Unset, float]):
        time_correction (Union[Unset, float]):
        f_p_time (Union[Unset, float]):
    """

    station_name: str
    p_arrival: datetime.datetime
    p_onset: Union[Unset, Onset] = Onset.VALUE_2
    p_phase_descriptor: Union[Unset, PhaseDescriptorP] = PhaseDescriptorP.VALUE_4
    p_first_motion: Union[Unset, FirstMotion] = UNSET
    s_arrival: Union[Unset, datetime.datetime] = UNSET
    p_weight: Union[Unset, int] = UNSET
    s_onset: Union[Unset, Onset] = Onset.VALUE_2
    s_phase_descriptor: Union[Unset, PhaseDescriptorS] = PhaseDescriptorS.VALUE_3
    s_remark: Union[Unset, str] = "   "
    s_first_motion: Union[Unset, FirstMotion] = UNSET
    s_weight: Union[Unset, int] = UNSET
    amplitude: Union[Unset, float] = UNSET
    period: Union[Unset, float] = UNSET
    time_correction: Union[Unset, float] = UNSET
    f_p_time: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        station_name = self.station_name
        p_arrival = self.p_arrival.isoformat()

        p_onset: Union[Unset, str] = UNSET
        if not isinstance(self.p_onset, Unset):
            p_onset = self.p_onset.value

        p_phase_descriptor: Union[Unset, str] = UNSET
        if not isinstance(self.p_phase_descriptor, Unset):
            p_phase_descriptor = self.p_phase_descriptor.value

        p_first_motion: Union[Unset, str] = UNSET
        if not isinstance(self.p_first_motion, Unset):
            p_first_motion = self.p_first_motion.value

        s_arrival: Union[Unset, str] = UNSET
        if not isinstance(self.s_arrival, Unset):
            s_arrival = self.s_arrival.isoformat()

        p_weight = self.p_weight
        s_onset: Union[Unset, str] = UNSET
        if not isinstance(self.s_onset, Unset):
            s_onset = self.s_onset.value

        s_phase_descriptor: Union[Unset, str] = UNSET
        if not isinstance(self.s_phase_descriptor, Unset):
            s_phase_descriptor = self.s_phase_descriptor.value

        s_remark = self.s_remark
        s_first_motion: Union[Unset, str] = UNSET
        if not isinstance(self.s_first_motion, Unset):
            s_first_motion = self.s_first_motion.value

        s_weight = self.s_weight
        amplitude = self.amplitude
        period = self.period
        time_correction = self.time_correction
        f_p_time = self.f_p_time

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "station_name": station_name,
                "p_arrival": p_arrival,
            }
        )
        if p_onset is not UNSET:
            field_dict["p_onset"] = p_onset
        if p_phase_descriptor is not UNSET:
            field_dict["p_phase_descriptor"] = p_phase_descriptor
        if p_first_motion is not UNSET:
            field_dict["p_first_motion"] = p_first_motion
        if s_arrival is not UNSET:
            field_dict["s_arrival"] = s_arrival
        if p_weight is not UNSET:
            field_dict["p_weight"] = p_weight
        if s_onset is not UNSET:
            field_dict["s_onset"] = s_onset
        if s_phase_descriptor is not UNSET:
            field_dict["s_phase_descriptor"] = s_phase_descriptor
        if s_remark is not UNSET:
            field_dict["s_remark"] = s_remark
        if s_first_motion is not UNSET:
            field_dict["s_first_motion"] = s_first_motion
        if s_weight is not UNSET:
            field_dict["s_weight"] = s_weight
        if amplitude is not UNSET:
            field_dict["amplitude"] = amplitude
        if period is not UNSET:
            field_dict["period"] = period
        if time_correction is not UNSET:
            field_dict["time_correction"] = time_correction
        if f_p_time is not UNSET:
            field_dict["f_p_time"] = f_p_time

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        station_name = d.pop("station_name")

        p_arrival = isoparse(d.pop("p_arrival"))

        _p_onset = d.pop("p_onset", UNSET)
        p_onset: Union[Unset, Onset]
        if isinstance(_p_onset, Unset):
            p_onset = UNSET
        else:
            p_onset = Onset(_p_onset)

        _p_phase_descriptor = d.pop("p_phase_descriptor", UNSET)
        p_phase_descriptor: Union[Unset, PhaseDescriptorP]
        if isinstance(_p_phase_descriptor, Unset):
            p_phase_descriptor = UNSET
        else:
            p_phase_descriptor = PhaseDescriptorP(_p_phase_descriptor)

        _p_first_motion = d.pop("p_first_motion", UNSET)
        p_first_motion: Union[Unset, FirstMotion]
        if isinstance(_p_first_motion, Unset):
            p_first_motion = UNSET
        else:
            p_first_motion = FirstMotion(_p_first_motion)

        _s_arrival = d.pop("s_arrival", UNSET)
        s_arrival: Union[Unset, datetime.datetime]
        if isinstance(_s_arrival, Unset):
            s_arrival = UNSET
        else:
            s_arrival = isoparse(_s_arrival)

        p_weight = d.pop("p_weight", UNSET)

        _s_onset = d.pop("s_onset", UNSET)
        s_onset: Union[Unset, Onset]
        if isinstance(_s_onset, Unset):
            s_onset = UNSET
        else:
            s_onset = Onset(_s_onset)

        _s_phase_descriptor = d.pop("s_phase_descriptor", UNSET)
        s_phase_descriptor: Union[Unset, PhaseDescriptorS]
        if isinstance(_s_phase_descriptor, Unset):
            s_phase_descriptor = UNSET
        else:
            s_phase_descriptor = PhaseDescriptorS(_s_phase_descriptor)

        s_remark = d.pop("s_remark", UNSET)

        _s_first_motion = d.pop("s_first_motion", UNSET)
        s_first_motion: Union[Unset, FirstMotion]
        if isinstance(_s_first_motion, Unset):
            s_first_motion = UNSET
        else:
            s_first_motion = FirstMotion(_s_first_motion)

        s_weight = d.pop("s_weight", UNSET)

        amplitude = d.pop("amplitude", UNSET)

        period = d.pop("period", UNSET)

        time_correction = d.pop("time_correction", UNSET)

        f_p_time = d.pop("f_p_time", UNSET)

        phase_reading = cls(
            station_name=station_name,
            p_arrival=p_arrival,
            p_onset=p_onset,
            p_phase_descriptor=p_phase_descriptor,
            p_first_motion=p_first_motion,
            s_arrival=s_arrival,
            p_weight=p_weight,
            s_onset=s_onset,
            s_phase_descriptor=s_phase_descriptor,
            s_remark=s_remark,
            s_first_motion=s_first_motion,
            s_weight=s_weight,
            amplitude=amplitude,
            period=period,
            time_correction=time_correction,
            f_p_time=f_p_time,
        )

        phase_reading.additional_properties = d
        return phase_reading

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="HorizontalUncertainty")


@attr.s(auto_attribs=True)
class HorizontalUncertainty:
    """
    Attributes:
        max_horizontal_uncertainty_m (float):
        min_horizontal_uncertainty_m (float):
        azimuth_max_horizontal_uncertainty_deg (float):
    """

    max_horizontal_uncertainty_m: float
    min_horizontal_uncertainty_m: float
    azimuth_max_horizontal_uncertainty_deg: float
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        max_horizontal_uncertainty_m = self.max_horizontal_uncertainty_m
        min_horizontal_uncertainty_m = self.min_horizontal_uncertainty_m
        azimuth_max_horizontal_uncertainty_deg = self.azimuth_max_horizontal_uncertainty_deg

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "max_horizontal_uncertainty_m": max_horizontal_uncertainty_m,
                "min_horizontal_uncertainty_m": min_horizontal_uncertainty_m,
                "azimuth_max_horizontal_uncertainty_deg": azimuth_max_horizontal_uncertainty_deg,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        max_horizontal_uncertainty_m = d.pop("max_horizontal_uncertainty_m")

        min_horizontal_uncertainty_m = d.pop("min_horizontal_uncertainty_m")

        azimuth_max_horizontal_uncertainty_deg = d.pop("azimuth_max_horizontal_uncertainty_deg")

        horizontal_uncertainty = cls(
            max_horizontal_uncertainty_m=max_horizontal_uncertainty_m,
            min_horizontal_uncertainty_m=min_horizontal_uncertainty_m,
            azimuth_max_horizontal_uncertainty_deg=azimuth_max_horizontal_uncertainty_deg,
        )

        horizontal_uncertainty.additional_properties = d
        return horizontal_uncertainty

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



""" Contains all the data models used in inputs/outputs """

from .first_motion import FirstMotion
from .horizontal_uncertainty import HorizontalUncertainty
from .http_validation_error import HTTPValidationError
from .location_request_nl_loc import LocationRequestNLLoc
from .onset import Onset
from .origin import Origin
from .phase_descriptor_p import PhaseDescriptorP
from .phase_descriptor_s import PhaseDescriptorS
from .phase_reading import PhaseReading
from .station_lat_lng import StationLatLng
from .validation_error import ValidationError
from .velocity_layer_1d import VelocityLayer1D
from .velocity_model_1d import VelocityModel1D

__all__ = (
    "FirstMotion",
    "HorizontalUncertainty",
    "HTTPValidationError",
    "LocationRequestNLLoc",
    "Onset",
    "Origin",
    "PhaseDescriptorP",
    "PhaseDescriptorS",
    "PhaseReading",
    "StationLatLng",
    "ValidationError",
    "VelocityLayer1D",
    "VelocityModel1D",
)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.phase_reading import PhaseReading
    from ..models.station_lat_lng import StationLatLng
    from ..models.velocity_model_1d import VelocityModel1D


T = TypeVar("T", bound="LocationRequestNLLoc")


@attr.s(auto_attribs=True)
class LocationRequestNLLoc:
    """
    Attributes:
        velocity_model (VelocityModel1D):
        stations (List['StationLatLng']):
        events (List[List['PhaseReading']]):
    """

    velocity_model: "VelocityModel1D"
    stations: List["StationLatLng"]
    events: List[List["PhaseReading"]]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        velocity_model = self.velocity_model.to_dict()

        stations = []
        for stations_item_data in self.stations:
            stations_item = stations_item_data.to_dict()

            stations.append(stations_item)

        events = []
        for events_item_data in self.events:
            events_item = []
            for events_item_item_data in events_item_data:
                events_item_item = events_item_item_data.to_dict()

                events_item.append(events_item_item)

            events.append(events_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "velocity_model": velocity_model,
                "stations": stations,
                "events": events,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.phase_reading import PhaseReading
        from ..models.station_lat_lng import StationLatLng
        from ..models.velocity_model_1d import VelocityModel1D

        d = src_dict.copy()
        velocity_model = VelocityModel1D.from_dict(d.pop("velocity_model"))

        stations = []
        _stations = d.pop("stations")
        for stations_item_data in _stations:
            stations_item = StationLatLng.from_dict(stations_item_data)

            stations.append(stations_item)

        events = []
        _events = d.pop("events")
        for events_item_data in _events:
            events_item = []
            _events_item = events_item_data
            for events_item_item_data in _events_item:
                events_item_item = PhaseReading.from_dict(events_item_item_data)

                events_item.append(events_item_item)

            events.append(events_item)

        location_request_nl_loc = cls(
            velocity_model=velocity_model,
            stations=stations,
            events=events,
        )

        location_request_nl_loc.additional_properties = d
        return location_request_nl_loc

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['fast_hypo_client',
 'fast_hypo_client.api',
 'fast_hypo_client.api.non_lin_loc',
 'fast_hypo_client.models']

package_data = \
{'': ['*']}

install_requires = \
['attrs>=21.3.0', 'httpx>=0.15.4,<0.24.0', 'python-dateutil>=2.8.0,<3.0.0']

setup_kwargs = {
    'name': 'fast-hypo-client',
    'version': '0.1.1',
    'description': 'A client library for accessing Fast-Hypo',
    'long_description': '# API Client for Earthquake Location\n\n## Usage\n\n```py\nfrom datetime import datetime\nimport requests\n\nfrom fast_hypo_client.models import VelocityLayer1D, VelocityModel1D, PhaseReading, StationLatLng, PhaseDescriptorP, FirstMotion, LocationRequestNLLoc\nfrom fast_hypo_client.client import Client\nfrom fast_hypo_client.api.non_lin_loc import locate_nlloc_locate_nlloc_post\n\nvelocity_model = VelocityModel1D(\n    layers=[\n        VelocityLayer1D(\n            depth_km=0.0,\n            vp_top=4.0,\n            vs_top=2.38,\n            rho_top=2.7,\n            vp_grad=0.0,\n            vs_grad=0.0,\n            rho_grad=0.0,\n        ),\n        VelocityLayer1D(\n            depth_km=2.0,\n            vp_top=6.0,\n            vs_top=3.57,\n            rho_top=2.7,\n            vp_grad=0.0,\n            vs_grad=0.0,\n            rho_grad=0.0,\n        ),\n        VelocityLayer1D(\n            depth_km=10.0,\n            vp_top=6.3,\n            vs_top=3.75,\n            rho_top=2.7,\n            vp_grad=0.0,\n            vs_grad=0.0,\n            rho_grad=0.0,\n        ),\n    ]\n)\n\nstations = [\n    StationLatLng(\n        code="SBF",\n        latitude=43.8635,\n        longitude=7.43483,\n        elevation_km=0.847,\n        depth_km=0.0,\n    ),\n    StationLatLng(\n        code="CEPP",\n        latitude=43.9163,\n        longitude=7.7465,\n        elevation_km=1.08,\n        depth_km=0.0,\n    ),\n    StationLatLng(\n        code="MVIF",\n        latitude=43.8965,\n        longitude=7.1525,\n        elevation_km=1.48,\n        depth_km=0.0,\n    ),\n    StationLatLng(\n        code="IMI",\n        latitude=43.9105,\n        longitude=7.89317,\n        elevation_km=0.84,\n        depth_km=0.0,\n    ),\n]\n\nevents = [\n    [\n        PhaseReading(\n            station_name="SBF",\n            p_phase_descriptor=PhaseDescriptorP.P,\n            p_arrival=datetime.fromisoformat("1995-04-21T08:03:00.260"),\n        ),\n        PhaseReading(\n            station_name="CEPP",\n            p_phase_descriptor=PhaseDescriptorP.P,\n            p_first_motion=FirstMotion.UP,\n            p_arrival=datetime.fromisoformat("1995-04-21T08:03:01.140"),\n        ),\n        PhaseReading(\n            station_name="MVIF",\n            p_phase_descriptor=PhaseDescriptorP.P,\n            p_weight=0,\n            p_arrival=datetime.fromisoformat("1995-04-21T08:03:03.580"),\n            s_arrival=datetime.fromisoformat("1995-04-21T08:03:08.680"),\n        ),\n        PhaseReading(\n            station_name="IMI",\n            p_phase_descriptor=PhaseDescriptorP.P,\n            p_weight=0,\n            p_arrival=datetime.fromisoformat("1995-04-21T08:03:02.770"),\n        ),\n    ]\n]\n\nrequest = LocationRequestNLLoc(\n    events=events,\n    stations=stations,\n    velocity_model=velocity_model,\n)\n\nclient = Client(base_url="https://fast-hypo.fly.dev")\n\nlocate_nlloc_locate_nlloc_post.sync_detailed(client=client, json_body=request)\n```',
    'author': 'None',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
